VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package helloJavaWorld

Package {helloJavaWorld}


Version: 0.0-9
Date: 2014-09-03
Title: Hello Java World
Author: Tobias Verbeke
Maintainer: Tobias Verbeke <tobias.verbeke@openanalytics.eu>
Description: A dummy package to demonstrate how to interface to a jar file that resides inside an R package.
Depends: R (≥ 2.7.0), rJava (≥ 0.5-0)
SystemRequirements: Java (>= 1.5)
License: GPL-3
Packaged: 2014-09-04 13:17:36 UTC; tverbeke
Repository: CRAN
Date/Publication: 2014-09-04 15:41:44
NeedsCompilation: no

Function to say hello from a Java class

Description

This function executes a method of a Java class defined in a JAR inside the R package.

Usage

  helloJavaWorld()

Details

Details are given in the package vignette.

Value

The string "Hello Java World!" is returned.

Author(s)

Tobias Verbeke

Examples

  helloJavaWorld()

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.