| Title: | Hello Java World |
|---|---|
| Description: | A dummy package to demonstrate how to interface to a jar file that resides inside an R package. |
| Authors: | Tobias Verbeke |
| Maintainer: | Tobias Verbeke <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0-9 |
| Built: | 2026-06-10 09:45:48 UTC |
| Source: | https://github.com/cran/helloJavaWorld |
This function executes a method of a Java class defined in a JAR inside the R package.
helloJavaWorld()helloJavaWorld()
Details are given in the package vignette.
The string "Hello Java World!" is returned.
Tobias Verbeke
helloJavaWorld()helloJavaWorld()